﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Data;
using System.Xml;
using System.IO;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using System.Text;
using CMS.CMSHelper;


/// <summary>
/// Class providing helper methods for the web services.
/// </summary>
public class ServiceHelper
{
     /// <summary>
    /// Returns users who match the specified search expression.
    /// </summary>
    /// <param name="searchExpression">Search expression</param>
    public static string GetUsers(string searchExpression)
    {
        // Build WHERE condition according to the search expression
        string where = "";
        if (searchExpression != "")
        {
            searchExpression = searchExpression.Replace("'", "''");

            StringBuilder builder = new StringBuilder();
            builder.Append("(UserName LIKE '%" + searchExpression + "%') OR ");
            builder.Append("(FirstName LIKE '%" + searchExpression + "%') OR ");
            builder.Append("(MiddleName LIKE '%" + searchExpression + "%') OR ");
            builder.Append("(LastName LIKE '%" + searchExpression + "%') OR ");
            builder.Append("(FullName LIKE '%" + searchExpression + "%') OR ");
            builder.Append("(Email LIKE '%" + searchExpression + "%')");
            where = builder.ToString();
        }

        // Get the data
        DataSet ds = UserInfoProvider.GetUsers(where, null);
        return GetXmlData(ds, "users", "user", "fullname;email");
    }


    /// <summary>
    /// Returns documents which match the specified search expression.
    /// </summary>
    /// <param name="searchExpression">Search expression (document name or its part).</param>
    public static string GetDocuments(string searchExpression)
    {
        // Build WHERE condition according to the search expression
        string where = "";
        if (searchExpression != "")
        {
            where = "DocumentName LIKE '%" + searchExpression.Replace("'", "''") + "%'";
        }

        // Example of the customization to get the requested data 
        // (other parameters can be customized as well):

        string siteName = CMSContext.CurrentSiteName; // documents from current site
        // siteName = "anothersitename"; //  documents from another site

        string path = "/%"; // all documents from the root section = all documents
        // path = "/News/%"; // all documents from the /News section

        string docTypes = ""; // all document types
        // docTypes = "cms.news;cms.menuitem";  // only specified document types

        string culture = TreeProvider.ALL_CULTURES; // documents from all cultures
        // culture = "en-us"; // only documents from specified culture

        string orderBy = "DocumentName"; // Order by DocumentName
        // orderBy = "NewsTitle"; // Order by NewsTitle, cms.news document type must be included

        // Get requested documents 
        DataSet ds = TreeHelper.GetDocuments(siteName, path, culture, false, docTypes, where, 
            orderBy, TreeProvider.ALL_LEVELS, true, -1);

        return GetXmlData(ds, "documents", "document", "documentname");
    }


    /// <summary>
    /// Returns XML including specified columns from the DataSet.
    /// </summary>
    /// <param name="ds">Data set with  data.</param>
    /// <param name="rootName">XML root node name.</param>
    /// <param name="elementName">Element node name.</param>
    /// <param name="columns">Columns which should be included in the output XML. Format: column1;column2;...</param>
    private static string GetXmlData(DataSet ds, string rootName, string elementName, string columns)
    {
        // Crate root node
        XmlDocument xml = new XmlDocument();
        XmlElement elemRoot = xml.CreateElement(rootName);
        xml.AppendChild(elemRoot);

        // Modify columns to enable determining if some column is included
        columns = ";" + columns.ToLower().Trim(';') + ";";

        // Add elements
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                // Create element node
                XmlElement elem = xml.CreateElement(elementName);

                foreach (DataColumn col in dr.Table.Columns)
                {
                    // If column should be included in the output XML
                    if (columns.Contains(";" + col.ColumnName.ToLower() + ";"))
                    {
                        // Add element attributes
                        XmlAttribute attrib = xml.CreateAttribute(col.ColumnName);
                        attrib.Value = Convert.ToString(dr[col.ColumnName]);
                        elem.Attributes.Append(attrib);
                        break;
                    }
                }

                // Add element node
                elemRoot.AppendChild(elem);
            }
        }
        return xml.OuterXml;
    }
}

